<?xml version="1.0" ?><!DOCTYPE TS><TS language="ru" version="2.1">
<context>
    <name>dcc::keyboard::Language</name>
    <message>
        <location filename="language.h" line="31"/>
        <source>Afar</source>
        <translation>Afar</translation>
    </message>
    <message>
        <location filename="language.h" line="32"/>
        <source>Afrikaans</source>
        <translation>Afrikaans</translation>
    </message>
    <message>
        <location filename="language.h" line="33"/>
        <source>አማርኛ</source>
        <translation>አማርኛ</translation>
    </message>
    <message>
        <location filename="language.h" line="34"/>
        <source>عربية</source>
        <translation>عربية</translation>
    </message>
    <message>
        <location filename="language.h" line="35"/>
        <source>অসমীয়া</source>
        <translation>অসমীয়া</translation>
    </message>
    <message>
        <location filename="language.h" line="36"/>
        <source>Asturianu</source>
        <translation>Asturianu</translation>
    </message>
    <message>
        <location filename="language.h" line="37"/>
        <source>Беларуская</source>
        <translation>Asturianu</translation>
    </message>
    <message>
        <location filename="language.h" line="38"/>
        <source>Biełaruskaja łacinka</source>
        <translation>Беларускі лацінкавы</translation>
    </message>
    <message>
        <location filename="language.h" line="39"/>
        <source>Български</source>
        <translation>Български</translation>
    </message>
    <message>
        <location filename="language.h" line="40"/>
        <source>বাংলা</source>
        <translation>বাংলা</translation>
    </message>
    <message>
        <location filename="language.h" line="41"/>
        <source>বাংলা (ভারত)</source>
        <translation>বাংলা (ভারত)</translation>
    </message>
    <message>
        <location filename="language.h" line="42"/>
        <source>བོད་སྐད།</source>
        <translation>བོད་སྐད།</translation>
    </message>
    <message>
        <location filename="language.h" line="43"/>
        <source>Brezhoneg</source>
        <translation>Brezhoneg</translation>
    </message>
    <message>
        <location filename="language.h" line="44"/>
        <source>Bosanski</source>
        <translation>Bosanski</translation>
    </message>
    <message>
        <location filename="language.h" line="45"/>
        <source>Català</source>
        <translation>Català</translation>
    </message>
    <message>
        <location filename="language.h" line="46"/>
        <source>Qırımtatarca</source>
        <translation>Qırımtatarca</translation>
    </message>
    <message>
        <location filename="language.h" line="47"/>
        <source>Český</source>
        <translation>Český</translation>
    </message>
    <message>
        <location filename="language.h" line="48"/>
        <source>Kaszëbsczi</source>
        <translation>Kaszëbsczi</translation>
    </message>
    <message>
        <location filename="language.h" line="49"/>
        <source>Чăвашла</source>
        <translation>Чăвашла</translation>
    </message>
    <message>
        <location filename="language.h" line="50"/>
        <source>Cymraeg</source>
        <translation>Cymraeg</translation>
    </message>
    <message>
        <location filename="language.h" line="51"/>
        <source>Dansk</source>
        <translation>Dansk</translation>
    </message>
    <message>
        <location filename="language.h" line="52"/>
        <source>Deutsch</source>
        <translation>Deutsch</translation>
    </message>
    <message>
        <location filename="language.h" line="53"/>
        <source>ཇོང་ཁ</source>
        <translation>ཇོང་ཁ</translation>
    </message>
    <message>
        <location filename="language.h" line="54"/>
        <source>Ελληνικά</source>
        <translation>Ελληνικά</translation>
    </message>
    <message>
        <location filename="language.h" line="55"/>
        <source>British English</source>
        <translation>British English</translation>
    </message>
    <message>
        <location filename="language.h" line="56"/>
        <source>American English</source>
        <translation>American English</translation>
    </message>
    <message>
        <location filename="language.h" line="57"/>
        <source>Español</source>
        <translation>Español</translation>
    </message>
    <message>
        <location filename="language.h" line="58"/>
        <source>Eesti</source>
        <translation>Eesti</translation>
    </message>
    <message>
        <location filename="language.h" line="59"/>
        <source>Euskara</source>
        <translation>Euskara</translation>
    </message>
    <message>
        <location filename="language.h" line="60"/>
        <source>فارسی</source>
        <translation>فارسی</translation>
    </message>
    <message>
        <location filename="language.h" line="61"/>
        <source>Suomi</source>
        <translation>Suomi</translation>
    </message>
    <message>
        <location filename="language.h" line="62"/>
        <source>Føroyskt</source>
        <translation>Føroyskt</translation>
    </message>
    <message>
        <location filename="language.h" line="63"/>
        <source>Français</source>
        <translation>Français</translation>
    </message>
    <message>
        <location filename="language.h" line="64"/>
        <source>Frysk</source>
        <translation>Frysk</translation>
    </message>
    <message>
        <location filename="language.h" line="65"/>
        <source>Gaeilge</source>
        <translation>Gaeilge</translation>
    </message>
    <message>
        <location filename="language.h" line="66"/>
        <source>Gàidhlig</source>
        <translation>Gaeilge</translation>
    </message>
    <message>
        <location filename="language.h" line="67"/>
        <source>Galego</source>
        <translation>Galego</translation>
    </message>
    <message>
        <location filename="language.h" line="68"/>
        <source>ગુજરાતી </source>
        <translation>ગુજરાતી</translation>
    </message>
    <message>
        <location filename="language.h" line="69"/>
        <source>Gaelg</source>
        <translation>Gaelg</translation>
    </message>
    <message>
        <location filename="language.h" line="70"/>
        <source>هَوُسَ</source>
        <translation>هَوُسَ</translation>
    </message>
    <message>
        <location filename="language.h" line="71"/>
        <source>עברית</source>
        <translation>עברית</translation>
    </message>
    <message>
        <location filename="language.h" line="72"/>
        <source>हिन्दी</source>
        <translation>हिन्दी</translation>
    </message>
    <message>
        <location filename="language.h" line="73"/>
        <source>Chhattisgarhi</source>
        <translation>हिन्दी</translation>
    </message>
    <message>
        <location filename="language.h" line="74"/>
        <source>Hrvatski</source>
        <translation>Hrvatski</translation>
    </message>
    <message>
        <location filename="language.h" line="75"/>
        <source>Hornjoserbsce</source>
        <translation>Hornjoserbsce</translation>
    </message>
    <message>
        <location filename="language.h" line="76"/>
        <source>Magyar</source>
        <translation>Magyar</translation>
    </message>
    <message>
        <location filename="language.h" line="77"/>
        <source>Հայերեն</source>
        <translation>Հայերեն</translation>
    </message>
    <message>
        <location filename="language.h" line="78"/>
        <source>Indonesia</source>
        <translation>Indonesia</translation>
    </message>
    <message>
        <location filename="language.h" line="79"/>
        <source>Iñupiak</source>
        <translation>Iñupiak</translation>
    </message>
    <message>
        <location filename="language.h" line="80"/>
        <source>Íslenska</source>
        <translation>Íslenska</translation>
    </message>
    <message>
        <location filename="language.h" line="81"/>
        <source>Italiano</source>
        <translation>Italiano</translation>
    </message>
    <message>
        <location filename="language.h" line="82"/>
        <source>ᐃᓄᒃᑎᑐᑦ</source>
        <translation>ᐃᓄᒃᑎᑐᑦ</translation>
    </message>
    <message>
        <location filename="language.h" line="83"/>
        <source>日本語</source>
        <translation>日本語</translation>
    </message>
    <message>
        <location filename="language.h" line="84"/>
        <source>ქართული</source>
        <translation>ქართული</translation>
    </message>
    <message>
        <location filename="language.h" line="85"/>
        <source>Қазақша</source>
        <translation>Қазақша</translation>
    </message>
    <message>
        <location filename="language.h" line="86"/>
        <source>Kalaallisut</source>
        <translation>Kalaallisut</translation>
    </message>
    <message>
        <location filename="language.h" line="87"/>
        <source>ខ្មែរ</source>
        <translation>ខ្មែរ</translation>
    </message>
    <message>
        <location filename="language.h" line="88"/>
        <source>ಕನ್ನಡ</source>
        <translation>ಕನ್ನಡ</translation>
    </message>
    <message>
        <location filename="language.h" line="89"/>
        <source>한국어</source>
        <translation>한국어</translation>
    </message>
    <message>
        <location filename="language.h" line="90"/>
        <source>कश्मीरी - (كشميري)</source>
        <translation>Кашмирский - (باميري)</translation>
    </message>
    <message>
        <location filename="language.h" line="91"/>
        <source>Kurdî</source>
        <translation>Kurdî</translation>
    </message>
    <message>
        <location filename="language.h" line="92"/>
        <source>Kernewek</source>
        <translation>Kernewek</translation>
    </message>
    <message>
        <location filename="language.h" line="93"/>
        <source>Кыргызча</source>
        <translation>Кыргызча</translation>
    </message>
    <message>
        <location filename="language.h" line="94"/>
        <source>Lëtzebuergesch</source>
        <translation>Lëtzebuergesch</translation>
    </message>
    <message>
        <location filename="language.h" line="95"/>
        <source>Limburgs</source>
        <translation>Limburgs</translation>
    </message>
    <message>
        <location filename="language.h" line="96"/>
        <source>ລາວ</source>
        <translation>ລາວ</translation>
    </message>
    <message>
        <location filename="language.h" line="97"/>
        <source>Lietuvių</source>
        <translation>Lietuvių</translation>
    </message>
    <message>
        <location filename="language.h" line="98"/>
        <source>Latviešu</source>
        <translation>Latviešu</translation>
    </message>
    <message>
        <location filename="language.h" line="99"/>
        <source>Maithili</source>
        <translation>Maithili</translation>
    </message>
    <message>
        <location filename="language.h" line="100"/>
        <source>Malagasy</source>
        <translation>Malagasy</translation>
    </message>
    <message>
        <location filename="language.h" line="101"/>
        <source>Ebon</source>
        <translation>Ebon</translation>
    </message>
    <message>
        <location filename="language.h" line="102"/>
        <source>Māori</source>
        <translation>Māori</translation>
    </message>
    <message>
        <location filename="language.h" line="103"/>
        <source>Македонски</source>
        <translation>Македонски</translation>
    </message>
    <message>
        <location filename="language.h" line="104"/>
        <source>മലയാളം</source>
        <translation>മലയാളം</translation>
    </message>
    <message>
        <location filename="language.h" line="105"/>
        <source>Монгол</source>
        <translation>Монгол</translation>
    </message>
    <message>
        <location filename="language.h" line="106"/>
        <source>मराठी</source>
        <translation>मराठी</translation>
    </message>
    <message>
        <location filename="language.h" line="107"/>
        <source>Bahasa Melayu</source>
        <translation>Bahasa Melayu</translation>
    </message>
    <message>
        <location filename="language.h" line="108"/>
        <source>Malti</source>
        <translation>Malti</translation>
    </message>
    <message>
        <location filename="language.h" line="109"/>
        <source>Myanmasa</source>
        <translation>Myanmasa</translation>
    </message>
    <message>
        <location filename="language.h" line="110"/>
        <source>Ekakairũ Naoero</source>
        <translation>Ekakairũ Naoero</translation>
    </message>
    <message>
        <location filename="language.h" line="111"/>
        <source>Norsk (bokmål)</source>
        <translation>Norsk (bokmål)</translation>
    </message>
    <message>
        <location filename="language.h" line="112"/>
        <source>Plattdüütsch</source>
        <translation>Plattdüütsch</translation>
    </message>
    <message>
        <location filename="language.h" line="113"/>
        <source>नेपाली</source>
        <translation>नेपाली</translation>
    </message>
    <message>
        <location filename="language.h" line="114"/>
        <source>Nederlands</source>
        <translation>Nederlands</translation>
    </message>
    <message>
        <location filename="language.h" line="115"/>
        <source>Norsk (nynorsk)</source>
        <translation>Norsk (nynorsk)</translation>
    </message>
    <message>
        <location filename="language.h" line="116"/>
        <source>IsiNdebele</source>
        <translation>IsiNdebele</translation>
    </message>
    <message>
        <location filename="language.h" line="117"/>
        <source>Sesotho sa Leboa</source>
        <translation>Sesotho sa Leboa</translation>
    </message>
    <message>
        <location filename="language.h" line="118"/>
        <source>Occitan</source>
        <translation>Occitan</translation>
    </message>
    <message>
        <location filename="language.h" line="119"/>
        <source>Oromoo</source>
        <translation>Oromoo</translation>
    </message>
    <message>
        <location filename="language.h" line="120"/>
        <source>ଓଡ଼ିଆ</source>
        <translation>ଓଡ଼ିଆ</translation>
    </message>
    <message>
        <location filename="language.h" line="121"/>
        <source>Иронау</source>
        <translation>Иронау</translation>
    </message>
    <message>
        <location filename="language.h" line="122"/>
        <source>ਪੰਜਾਬੀ</source>
        <translation>ਪੰਜਾਬੀ</translation>
    </message>
    <message>
        <location filename="language.h" line="123"/>
        <source>Polski</source>
        <translation>Polski</translation>
    </message>
    <message>
        <location filename="language.h" line="124"/>
        <source>پښتو</source>
        <translation>پښتو</translation>
    </message>
    <message>
        <location filename="language.h" line="125"/>
        <source>Português</source>
        <translation>Português</translation>
    </message>
    <message>
        <location filename="language.h" line="126"/>
        <source>Português do Brasil</source>
        <translation>Português do Brasil</translation>
    </message>
    <message>
        <location filename="language.h" line="127"/>
        <source>Română</source>
        <translation>Română</translation>
    </message>
    <message>
        <location filename="language.h" line="128"/>
        <source>Русский</source>
        <translation>Русский</translation>
    </message>
    <message>
        <location filename="language.h" line="129"/>
        <source>Kinyarwanda</source>
        <translation>Kinyarwanda</translation>
    </message>
    <message>
        <location filename="language.h" line="130"/>
        <source>संस्कृत</source>
        <translation>संस्कृत</translation>
    </message>
    <message>
        <location filename="language.h" line="131"/>
        <source>Sardu</source>
        <translation>Sardu</translation>
    </message>
    <message>
        <location filename="language.h" line="132"/>
        <source>سنڌي</source>
        <translation>سنڌي</translation>
    </message>
    <message>
        <location filename="language.h" line="133"/>
        <source>Sámegiella</source>
        <translation>Sámegiella</translation>
    </message>
    <message>
        <location filename="language.h" line="134"/>
        <source>සිංහල</source>
        <translation>සිංහල</translation>
    </message>
    <message>
        <location filename="language.h" line="135"/>
        <source>Slovenčina</source>
        <translation>Slovenčina</translation>
    </message>
    <message>
        <location filename="language.h" line="136"/>
        <source>Slovenščina</source>
        <translation>Slovenščina</translation>
    </message>
    <message>
        <location filename="language.h" line="137"/>
        <source>Soomaaliga</source>
        <translation>Soomaaliga</translation>
    </message>
    <message>
        <location filename="language.h" line="138"/>
        <source>Shqip</source>
        <translation>Shqip</translation>
    </message>
    <message>
        <location filename="language.h" line="139"/>
        <source>Српски</source>
        <translation>Српски</translation>
    </message>
    <message>
        <location filename="language.h" line="140"/>
        <source>srpski (latinica)</source>
        <translation>srpski (latinica)</translation>
    </message>
    <message>
        <location filename="language.h" line="141"/>
        <source>SiSwati</source>
        <translation>SiSwati</translation>
    </message>
    <message>
        <location filename="language.h" line="142"/>
        <source>Sesotho</source>
        <translation>Sesotho</translation>
    </message>
    <message>
        <location filename="language.h" line="143"/>
        <source>Svenska</source>
        <translation>Svenska</translation>
    </message>
    <message>
        <location filename="language.h" line="144"/>
        <source>Swahili</source>
        <translation>Swahili</translation>
    </message>
    <message>
        <location filename="language.h" line="145"/>
        <source>தமிழ்</source>
        <translation>தமிழ்</translation>
    </message>
    <message>
        <location filename="language.h" line="146"/>
        <source>తెలుగు</source>
        <translation>తెలుగు</translation>
    </message>
    <message>
        <location filename="language.h" line="147"/>
        <source>Тоҷикӣ</source>
        <translation>Тоҷикӣ</translation>
    </message>
    <message>
        <location filename="language.h" line="148"/>
        <source>ภาษาไทย</source>
        <translation>ภาษาไทย</translation>
    </message>
    <message>
        <location filename="language.h" line="149"/>
        <source>ትግርኛ</source>
        <translation>ትግርኛ</translation>
    </message>
    <message>
        <location filename="language.h" line="150"/>
        <source>Türkmen</source>
        <translation>Türkmen</translation>
    </message>
    <message>
        <location filename="language.h" line="151"/>
        <source>Setswana</source>
        <translation>Setswana</translation>
    </message>
    <message>
        <location filename="language.h" line="152"/>
        <source>Türkçe</source>
        <translation>Türkçe</translation>
    </message>
    <message>
        <location filename="language.h" line="153"/>
        <source>Xitsonga</source>
        <translation>Xitsonga</translation>
    </message>
    <message>
        <location filename="language.h" line="154"/>
        <source>Татарский</source>
        <translation>Татарский</translation>
    </message>
    <message>
        <location filename="language.h" line="155"/>
        <source>ئۇيغۇرچە</source>
        <translation>ئۇيغۇرچە</translation>
    </message>
    <message>
        <location filename="language.h" line="156"/>
        <source>Українська</source>
        <translation>Українська</translation>
    </message>
    <message>
        <location filename="language.h" line="157"/>
        <source>اردو</source>
        <translation>اردو</translation>
    </message>
    <message>
        <location filename="language.h" line="158"/>
        <source>Oʻzbekcha</source>
        <translation>Oʻzbekcha</translation>
    </message>
    <message>
        <location filename="language.h" line="159"/>
        <source>Uzbek (Cyrillic)</source>
        <translation>Uzbek (Cyrillic)</translation>
    </message>
    <message>
        <location filename="language.h" line="160"/>
        <source>Venda</source>
        <translation>Venda</translation>
    </message>
    <message>
        <location filename="language.h" line="161"/>
        <source>Tiếng Việt</source>
        <translation>Tiếng Việt</translation>
    </message>
    <message>
        <location filename="language.h" line="162"/>
        <source>Walon</source>
        <translation>Walon</translation>
    </message>
    <message>
        <location filename="language.h" line="163"/>
        <source>Wolof</source>
        <translation>Wolof</translation>
    </message>
    <message>
        <location filename="language.h" line="164"/>
        <source>isixhosa</source>
        <translation>isixhosa</translation>
    </message>
    <message>
        <location filename="language.h" line="165"/>
        <source>ייִדיש</source>
        <translation>ייִדיש</translation>
    </message>
    <message>
        <location filename="language.h" line="166"/>
        <source>Yorùbá</source>
        <translation>Yorùbá</translation>
    </message>
    <message>
        <location filename="language.h" line="167"/>
        <source>简体中文</source>
        <translation>简体中文</translation>
    </message>
    <message>
        <location filename="language.h" line="168"/>
        <source>繁體中文(香港)</source>
        <translation>繁體中文(香港)</translation>
    </message>
    <message>
        <location filename="language.h" line="169"/>
        <source>正體中文</source>
        <translation>正體中文</translation>
    </message>
    <message>
        <location filename="language.h" line="170"/>
        <source>isiZulu</source>
        <translation>isiZulu</translation>
    </message>
</context>
</TS>